@@ -5,7 +5,7 @@ use locale;
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK $HEBREW $SPANISH $ROMAN $POSTNOMINAL );
 
-$VERSION = '1.17';
+$VERSION = '1.18';
 
 #--------------------------------------------------------------------------
 # Modules
@@ -77,7 +77,7 @@ sub NameCase {
         # and return a name-cased copy.
         nc( ${ $_[0] } );
 
-    } elsif( scalar @_ == 1 and not ref $_[0] ) {
+    } elsif( scalar @_ == 1 ) {
         # We've received a scalar: we return a name-cased copy.
         nc( $_[0] );
 
@@ -93,6 +93,8 @@ sub nc {
     local( $_ ) = @_ if @_;
     $_ = ${$_} if ref( $_ ) ;           # Replace reference with value.
 
+    return $_   unless($_);
+
     $_ = lc ;                           # Lowercase the lot.
     s{ \b (\w)   }{\u$1}gx;             # Uppercase first letter of every word.
     s{ (\'\w) \b }{\L$1}gx;             # Lowercase 's.
